## main

## 1.1.1 / 2025-08-01
 - Changed repo structure to be more consistent with other esi repos (ie src/*)
 - Modified pypi instructions for deploying tagged releases

## 1.1.0 / 2025-08-01
 - First release
 - Updated numpy dependency to numpy>=1.26

